@@ -69,7 +69,7 @@ class ReCaptchaV3TaskProxyless:
         minScore: float,
         pageAction: str,
         **kwargs,
-    ):
+    ) -> dict:
         """
 		Метод решения ReCaptcha V3
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -86,7 +86,12 @@ class ReCaptchaV3TaskProxyless:
             )
         # вставляем в пайлоад адрес страницы и ключ-индентификатор рекапчи
         self.task_payload["task"].update(
-            {"websiteURL": websiteURL, "websiteKey": websiteKey}
+            {
+                "websiteURL": websiteURL,
+                "websiteKey": websiteKey,
+                "minScore": minScore,
+                "pageAction": pageAction,
+            }
         )
         # Отправляем на антикапчу пайлоад
         # в результате получаем JSON ответ содержащий номер решаемой капчи
@@ -164,7 +169,7 @@ class aioReCaptchaV3TaskProxyless:
     # Работа с капчёй
     async def captcha_handler(
         self, websiteURL: str, websiteKey: str, minScore: float, pageAction: str
-    ):
+    ) -> dict:
         """
 		Метод решения ReCaptcha V3
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -181,7 +186,12 @@ class aioReCaptchaV3TaskProxyless:
             )
         # вставляем в пайлоад адрес страницы и ключ-индентификатор рекапчи
         self.task_payload["task"].update(
-            {"websiteURL": websiteURL, "websiteKey": websiteKey}
+            {
+                "websiteURL": websiteURL,
+                "websiteKey": websiteKey,
+                "minScore": minScore,
+                "pageAction": pageAction,
+            }
         )
         # Отправляем на антикапчу пайлоад
         # в результате получаем JSON ответ содержащий номер решаемой капчи
