@@ -8,7 +8,7 @@ from requests.adapters import HTTPAdapter
 from python3_anticaptcha import get_result_url
 
 
-def get_sync_result(result_payload: dict, sleep_time: int):
+def get_sync_result(result_payload: dict, sleep_time: int) -> dict:
     # создаём сессию
     session = requests.Session()
     # выставляем кол-во попыток подключения к серверу при ошибке
@@ -23,13 +23,15 @@ def get_sync_result(result_payload: dict, sleep_time: int):
                 time.sleep(sleep_time)
             else:
                 captcha_response.update({"taskId": result_payload["taskId"]})
+                session.close()
                 return captcha_response
         else:
             captcha_response.update({"taskId": result_payload["taskId"]})
+            session.close()
             return captcha_response
 
 
-async def get_async_result(result_payload: dict, sleep_time: int):
+async def get_async_result(result_payload: dict, sleep_time: int) -> dict:
     # Отправляем запрос на статус решения капчи.
     async with aiohttp.ClientSession() as session:
         while True:
